@@ -5,7 +5,8 @@ from ..basic_test import Test
 from ..basic_suite import TestSuite
 from checking.helpers.others import short
 from checking.helpers.others import format_seconds
-from checking.helpers.others import print_splitter_line
+from checking.exceptions import SkipTestException
+from checking.exceptions import OnlyIfFailedException
 from checking.helpers.exception_traceback import get_trace_filtered_by_filename
 
 
@@ -21,27 +22,26 @@ class DefaultListener(Listener):
 
     def on_before_suite_failed(self, test_suite):
         super().on_before_suite_failed(test_suite)
-        print(f'Before suite "{test_suite.name}" failed! Process stopped!')
+        Listener.print_sync(f'Before suite "{test_suite.name}" failed! Process stopped!')
 
     def on_suite_starts(self, test_suite: TestSuite):
         super().on_suite_starts(test_suite)
-        print(f'Starting suite "{test_suite.name}"')
+        Listener.print_sync(f'Starting suite "{test_suite.name}"')
 
     def on_empty_suite(self, test_suite: TestSuite):
         super().on_empty_suite(test_suite)
-        print('No tests were found! Stopped...')
+        Listener.print_sync('No tests were found! Stopped...')
 
     def on_dry_run(self, test_suite: TestSuite):
         super().on_dry_run(test_suite)
-        print_splitter_line()
-        print("DRY RUN MODE! No real tests will be executed! All fixtures will be ignored!")
-        print_splitter_line()
+        text = f'{"-" * 10}\nDRY RUN MODE! No real tests will be executed! All fixtures will be ignored!\n{"-" * 10}'
+        Listener.print_sync(text)
 
     def on_suite_stop_with_max_fail(self, max_fail: int):
         super().on_suite_stop_with_max_fail(max_fail)
-        print_splitter_line()
-        print(f"ATTENTION! Suite stops because of reaching maximum count of failed tests={max_fail}")
-        print_splitter_line()
+        text = f'{"-" * 10}\nATTENTION! Suite stops because of reaching maximum count of failed tests={max_fail}' \
+               f'\n{"-" * 10}'
+        Listener.print_sync(text)
 
     def on_suite_ends(self, test_suite: TestSuite):
         super().on_suite_ends(test_suite)
@@ -58,6 +58,7 @@ class DefaultListener(Listener):
         print(f'Total tests: {all_count}, success tests: {success_count}, failed tests: {f_count}, broken tests: '
               f'{b_count}, ignored tests: {i_count}')
         print(f'Time elapsed: {elapsed}.')
+        print(f'Success percent: {success_count / (all_count):.2%}')
         if self.verbose == 3:
             if f_count:
                 print(f'\nFailed tests are:')
@@ -82,9 +83,9 @@ class DefaultListener(Listener):
                 print('')
                 self.counts = 0
         elif self.verbose > 1:
-            print_splitter_line()
             add_ = Listener._get_test_arg_short_without_new_line(test)
-            print(f'Test "{test}" {add_} SUCCESS!')
+            text = f'{"-" * 10}\nTest "{test}" {add_} SUCCESS!\n'
+            Listener.print_sync(text)
 
     def on_broken(self, test: Test, exception_: Exception):
         super().on_broken(test, exception_)
@@ -97,21 +98,32 @@ class DefaultListener(Listener):
     def on_ignored(self, test: Test, fixture_type: str):
         super().on_ignored(test, fixture_type)
         add_ = '' if not test.argument else f'[{short(test.argument)}]'
-        print(f'Because of fixture "{fixture_type}" tests "{test}" {add_} was IGNORED!')
-        print_splitter_line()
+        text = f'Because of fixture "{fixture_type}" tests "{test}" {add_} was IGNORED!\n{"-" * 10}'
+        Listener.print_sync(text)
 
     def on_fixture_failed(self, group_name: str, fixture_type: str, exception_: Exception):
         super().on_fixture_failed(group_name, fixture_type, exception_)
-        print_splitter_line()
-        print(f'Fixture {fixture_type} "{group_name}" failed!')
+        text = f'{"-" * 10}\nFixture {fixture_type} "{group_name}" failed!\n'
         for tb in (e for e in traceback.extract_tb(exception_.__traceback__)):
-            print(f'File "{tb.filename}", line {tb.lineno}, in {tb.name}')
+            text = f'{text}File "{tb.filename}", line {tb.lineno}, in {tb.name}\n'
         print(exception_)
+        text = f'{text}{exception_}'
+        Listener.print_sync(text)
 
     def on_ignored_with_provider(self, test: Test):
         super().on_ignored_with_provider(test)
-        print(f'Provider "{test.provider}" for {test} not returns iterable or empty!'
-              f' All tests with provider were IGNORED!')
+        text = f'Provider "{test.provider}" for {test} not returns iterable or empty! ' \
+               f'All tests with provider were IGNORED!'
+        Listener.print_sync(text)
+
+    def on_error_with_provider(self, name: str, exc: Exception):
+        super().on_error_with_provider(name, exc)
+        Listener.print_sync(exc)
+
+    def on_before_provider_failed(self, test: Test, provider: str):
+        super().on_before_provider_failed(test, provider)
+        Listener.print_sync(f'Because of "before_test" all tests for {test} with data provider '
+                            f'"{provider}" was IGNORED!')
 
     def on_test_starts(self, test: Test):
         super().on_test_starts(test)
@@ -120,9 +132,12 @@ class DefaultListener(Listener):
         super().on_ignored_by_condition(test, exc)
         add_ = '' if not test.argument else f'[{short(test.argument)}]'
         if type(exc) is SystemExit:
-            print(f'Test "{test}" {add_} ignored because of sys.exit() call inside function!')
-        else:
-            print(f'Test "{test}" {add_} ignored because of condition ({test.only_if.__module__}.{test.only_if})!')
+            Listener.print_sync(f'Test "{test}" {add_} ignored because of sys.exit() call inside function!')
+        elif type(exc) is OnlyIfFailedException:
+            Listener.print_sync(
+                f'Test "{test}" {add_} ignored because of condition ({test.only_if.__module__}.{test.only_if})!')
+        elif type(exc) is SkipTestException:
+            Listener.print_sync(f'{exc.args[0]}\nTest "{test}" {add_} ignored because of test_skip() call!')
 
     def _failed_or_broken(self, test: Test, exception_: Exception, _result: str):
         _letter = f'{_result.upper()}!'
@@ -133,9 +148,9 @@ class DefaultListener(Listener):
                 print('')
                 self.counts = 0
         else:
+            text = ''
             if self.verbose > 0:
-                print_splitter_line()
+                text = f'{"-" * 10}\n'
             add_ = Listener._get_test_arg_short_without_new_line(test)
-            print(f'Test "{test}" {add_} {_letter}')
-            print(get_trace_filtered_by_filename(exception_))
-            print(exception_)
+            text = f'{text}Test "{test}" {add_} {_letter}\n{get_trace_filtered_by_filename(exception_)}\n{exception_}'
+            Listener.print_sync(text)
